module.exports = class EnvironmentService {
  constructor(settings = {}) {
    this.config = settings.config;
    this.public = settings.public || 'public';
    this.ignorePort = settings.ignorePort || false;
  }

  get environment() {
    return require('../config.json');
  }

  getPublicEnvironment(dirtyHost) {
    const host = this.getHost(dirtyHost);
    const config = this.config;
    const computedConfig = { firebase: config.firebase };

    delete config.firebase.credential;
    delete config.firebase.serviceAccount;

    const publicEnvironment = {
      firebase: config.firebase,
      [this.public]: Object.assign({}, config[this.public]),
    };

    if (publicEnvironment[this.public] && publicEnvironment[this.public][host]) {
      let overrides = publicEnvironment[this.public][host];
      for (let key in overrides) {
        publicEnvironment[this.public][key] = publicEnvironment[this.public][host][key];
      }
    }
    return publicEnvironment;
  }

  getHost(host) {
    if (host) {
      host = host.replace(/\./g, '_');

      if (this.ignorePort) {
        console.log('ignoring port');
        host = host.replace(/:\d+/, '');
      }
    }
    return host;
  }
};
